##  Why Is It Relevant?
  * Pace layering helps businesses categorize their business capabilities based on their pace of change. This allows them to prioritize their IT investments and resources based on the needs of each layer.
  * Pace layering enables you to establish different governing rules for different layers. This means that your IT governance efforts will be a balance of stability, agility, and innovation.
